@@ -15,9 +15,13 @@ EXPORT void CALL RomOpen (void)
 	api().RomOpen();
 }
 
-EXPORT void CALL CaptureScreen ( char * Directory )
+#ifdef LEGACY_ZILMAR_SPEC
+EXPORT void CALL CaptureScreen(char * Directory)
+#else
+EXPORT void CALL CaptureScreen(const char * Directory)
+#endif
 {
-	api().CaptureScreen(Directory);
+    api().CaptureScreen(Directory);
 }
 
 EXPORT void CALL CloseDLL (void)
@@ -25,19 +29,31 @@ EXPORT void CALL CloseDLL (void)
 	api().CloseDLL();
 }
 
-EXPORT void CALL DllAbout ( HWND hParent )
+#ifdef LEGACY_ZILMAR_SPEC
+EXPORT void CALL DllAbout(HWND hParent)
+#else
+EXPORT void CALL DllAbout(void * hParent)
+#endif
 {
-	api().DllAbout(/*hParent*/);
+    api().DllAbout(hParent);
 }
 
-EXPORT void CALL DllConfig ( HWND hParent )
+#ifdef LEGACY_ZILMAR_SPEC
+EXPORT void CALL DllConfig(HWND hParent)
+#else
+EXPORT void CALL DllConfig(void * hParent)
+#endif
 {
-	api().DllConfig(hParent);
+    api().DllConfig(hParent);
 }
 
-EXPORT void CALL DllTest ( HWND hParent )
+#ifdef LEGACY_ZILMAR_SPEC
+EXPORT void CALL DllTest(HWND hParent)
+#else
+EXPORT void CALL DllTest(void * hParent)
+#endif
 {
-	api().DllTest(hParent);
+    api().DllTest(hParent);
 }
 
 EXPORT void CALL DrawScreen (void)
@@ -65,4 +81,14 @@ void CALL mge_get_video_size(int32_t* width, int32_t* height)
 	api().GetVideoSize(width, height);
 }
 
+EXPORT void CALL PluginLoaded(void)
+{
+    // No-op or initialization if needed
+}
+
+EXPORT void CALL DrawStatus(const char * lpString, int32_t RightAlign)
+{
+    api().DrawStatus(lpString, RightAlign);
+}
+
 }
