@@ -1,6 +1,6 @@
 /*
  * Rosalie's Mupen GUI - https://github.com/Rosalie241/RMG
- *  Copyright (C) 2020-2025 Rosalie Wanders <rosalie@mailbox.org>
+ *  Copyright (C) 2020-2026 Rosalie Wanders <rosalie@mailbox.org>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 3.
@@ -54,11 +54,6 @@ enum class SettingsID
     Core_INPUT_Plugin,
     Core_RSP_Plugin,
 
-    // Core User Directory Settings
-    Core_OverrideUserDirs,
-    Core_UserDataDirOverride,
-    Core_UserCacheDirOverride,
-
     // Core 64DD ROM Settings
     Core_64DD_JapaneseIPL,
     Core_64DD_AmericanIPL,
@@ -466,6 +461,7 @@ enum class SettingsID
     GCAInput_Sensitivity,
     GCAInput_CButtonTreshold,
     GCAInput_TriggerTreshold,
+    GCAInput_SwapZL,
 
     Invalid
 };
