@@ -1,6 +1,6 @@
 /*
  * Rosalie's Mupen GUI - https://github.com/Rosalie241/RMG
- *  Copyright (C) 2020-2025 Rosalie Wanders <rosalie@mailbox.org>
+ *  Copyright (C) 2020-2026 Rosalie Wanders <rosalie@mailbox.org>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 3.
@@ -63,13 +63,13 @@ void AddCheatDialog::SetCheat(CoreCheat cheat)
     this->oldCheat = cheat;
 }
 
-void AddCheatDialog::setPlainTextEditLines(QPlainTextEdit* plainTextEdit, std::vector<std::string> lines)
+void AddCheatDialog::setPlainTextEditLines(QPlainTextEdit* plainTextEdit, const std::vector<std::string>& lines)
 {
     // reset text edit
     plainTextEdit->clear();
 
     // add lines
-    for (std::string& line : lines)
+    for (const std::string& line : lines)
     {
         plainTextEdit->appendPlainText(QString::fromStdString(line));
     }
