@@ -1,6 +1,6 @@
 /*
  * Rosalie's Mupen GUI - https://github.com/Rosalie241/RMG
- *  Copyright (C) 2020-2025 Rosalie Wanders <rosalie@mailbox.org>
+ *  Copyright (C) 2020-2026 Rosalie Wanders <rosalie@mailbox.org>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 3.
@@ -37,7 +37,7 @@ class AddCheatDialog : public QDialog, private Ui::AddCheatDialog
     CoreCheat oldCheat;
     QString file;
 
-    void setPlainTextEditLines(QPlainTextEdit* plainTextEdit, std::vector<std::string> lines);
+    void setPlainTextEditLines(QPlainTextEdit* plainTextEdit, const std::vector<std::string>& lines);
     bool validate(void);
     void validateOkButton(void);
 
