@@ -1,6 +1,6 @@
 /*
  * Rosalie's Mupen GUI - https://github.com/Rosalie241/RMG
- *  Copyright (C) 2020-2025 Rosalie Wanders <rosalie@mailbox.org>
+ *  Copyright (C) 2020-2026 Rosalie Wanders <rosalie@mailbox.org>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 3.
@@ -87,7 +87,7 @@ QList<QString> NetplayCommon::GetPluginNames(QString md5QString)
     return pluginNames;
 }
 
-void NetplayCommon::AddServers(QComboBox* comboBox, QJsonDocument document, bool dispatcher)
+void NetplayCommon::AddServers(QComboBox* comboBox, const QJsonDocument& document, bool dispatcher)
 {
     if (dispatcher)
     {
@@ -156,3 +156,10 @@ QString NetplayCommon::GetServerData(QComboBox* comboBox, int index)
 
     return comboBox->itemData(index).value<NetplayServerData>().Data;
 }
+
+QNetworkRequest NetplayCommon::GetNetworkRequest(QUrl url)
+{
+    QNetworkRequest networkRequest(url);
+    networkRequest.setRawHeader("netplay-id", "RMG");
+    return networkRequest;
+}
